==> intel-compute-runtime_23.35.27191.9.orig.tar.gz: compute-runtime-23.35.27191.9/shared/test/unit_test/pin/test_pin.cpp <==
/*
 * Copyright (C) 2022-2023 Intel Corporation
 *
 * SPDX-License-Identifier: MIT
 *
 */

#include "shared/source/pin/pin.h"
#include "shared/test/common/mocks/mock_os_library.h"

#include "gtest/gtest.h"

namespace ULT {

TEST(PinInitializationTest, GivenValidLibraryPinContextInitSucceeds) {
    uint32_t (*openPinHandler)(void *) = [](void *arg) -> uint32_t { return 0; };
    MockOsLibrary mockLibraryObject(reinterpret_cast<void *>(openPinHandler), false);
    MockOsLibrary::loadLibraryNewObject = &mockLibraryObject;
    NEO::PinContext::osLibraryLoadFunction = MockOsLibrary::load;
    std::string mockGTPinFunctionName{"aaa"};
    EXPECT_TRUE(NEO::PinContext::init(mockGTPinFunctionName));

    MockOsLibrary::loadLibraryNewObject = nullptr;
}

TEST(PinInitializationTest, GivenBadLibraryNamePinContextInitFAILS) {
    MockOsLibrary::loadLibraryNewObject = nullptr;
    NEO::PinContext::osLibraryLoadFunction = MockOsLibrary::load;
    std::string mockGTPinFunctionName{"aaa"};
    EXPECT_FALSE(NEO::PinContext::init(mockGTPinFunctionName));

    MockOsLibrary::loadLibraryNewObject = nullptr;
}

TEST(PinInitializationTest, GivenBadProcAddressPinContextInitFAILS) {
    MockOsLibrary mockLibraryObject(nullptr, false);
    MockOsLibrary::loadLibraryNewObject = &mockLibraryObject;
    NEO::PinContext::osLibraryLoadFunction = MockOsLibrary::load;
    std::string mockGTPinFunctionName{"aaa"};
    EXPECT_FALSE(NEO::PinContext::init(mockGTPinFunctionName));

    MockOsLibrary::loadLibraryNewObject = nullptr;
}

TEST(PinInitializationTest, GivenBadPinHandlerPinContextInitFAILS) {
    uint32_t (*openPinHandler)(void *) = [](void *arg) -> uint32_t { return 1; };
    MockOsLibrary mockLibraryObject(reinterpret_cast<void *>(openPinHandler), false);
    MockOsLibrary::loadLibraryNewObject = &mockLibraryObject;
    NEO::PinContext::osLibraryLoadFunction = MockOsLibrary::load;
    std::string mockGTPinFunctionName{"aaa"};
    EXPECT_FALSE(NEO::PinContext::init(mockGTPinFunctionName));

    MockOsLibrary::loadLibraryNewObject = nullptr;
}

} // namespace ULT

==> intel-compute-runtime_23.43.27642.40.orig.tar.gz: compute-runtime-23.43.27642.40/shared/test/unit_test/pin/test_pin.cpp <==
/*
 * Copyright (C) 2022-2023 Intel Corporation
 *
 * SPDX-License-Identifier: MIT
 *
 */

#include "shared/source/pin/pin.h"
#include "shared/test/common/mocks/mock_os_library.h"

#include "gtest/gtest.h"

namespace ULT {

TEST(PinInitializationTest, GivenValidLibraryPinContextInitSucceeds) {
    uint32_t (*openPinHandler)(void *) = [](void *arg) -> uint32_t { return 0; };
    MockOsLibrary::loadLibraryNewObject = new MockOsLibrary(reinterpret_cast<void *>(openPinHandler), false);
    NEO::PinContext::osLibraryLoadFunction = MockOsLibrary::load;
    std::string mockGTPinFunctionName{"aaa"};
    EXPECT_TRUE(NEO::PinContext::init(mockGTPinFunctionName));

    MockOsLibrary::loadLibraryNewObject = nullptr;
}

TEST(PinInitializationTest, GivenBadLibraryNamePinContextInitFAILS) {
    MockOsLibrary::loadLibraryNewObject = nullptr;
    NEO::PinContext::osLibraryLoadFunction = MockOsLibrary::load;
    std::string mockGTPinFunctionName{"aaa"};
    EXPECT_FALSE(NEO::PinContext::init(mockGTPinFunctionName));

    MockOsLibrary::loadLibraryNewObject = nullptr;
}

TEST(PinInitializationTest, GivenBadProcAddressPinContextInitFAILS) {
    MockOsLibrary::loadLibraryNewObject = new MockOsLibrary(nullptr, false);
    NEO::PinContext::osLibraryLoadFunction = MockOsLibrary::load;
    std::string mockGTPinFunctionName{"aaa"};
    EXPECT_FALSE(NEO::PinContext::init(mockGTPinFunctionName));

    MockOsLibrary::loadLibraryNewObject = nullptr;
}

TEST(PinInitializationTest, GivenBadPinHandlerPinContextInitFAILS) {
    uint32_t (*openPinHandler)(void *) = [](void *arg) -> uint32_t { return 1; };
    MockOsLibrary::loadLibraryNewObject = new MockOsLibrary(reinterpret_cast<void *>(openPinHandler), false);
    NEO::PinContext::osLibraryLoadFunction = MockOsLibrary::load;
    std::string mockGTPinFunctionName{"aaa"};
    EXPECT_FALSE(NEO::PinContext::init(mockGTPinFunctionName));

    MockOsLibrary::loadLibraryNewObject = nullptr;
}

} // namespace ULT
